flwr_oauth2/pkce
This module provides functions to create PKCE Verifiers and Challens as per RFC7636.
Types
The code challenge created from a code verifier
pub type Challenge {
Challenge(value: String)
}
Constructors
-
Challenge(value: String)
Values
pub fn new() -> Verifier
Creates a new code verifier as per RFC7636 4.1. Uses a default length for the verifier of 128.
For the definition of the code verifier see this excerpt from RFC7636:
high-entropy cryptographic random STRING using the unreserved characters [A-Z] / [a-z] / [0-9] / “-” / “.” / “_” / “~” from Section 2.3 of [RFC3986], with a minimum length of 43 characters and a maximum length of 128 characters.